@@ -1,31 +1,32 @@
 import shutil
 
-from unit.applications.proto import TestApplicationProto
+from unit.applications.proto import ApplicationProto
 from unit.option import option
 from unit.utils import public_dir
 
 
-class TestApplicationRuby(TestApplicationProto):
-    application_type = "ruby"
+class ApplicationRuby(ApplicationProto):
+    def __init__(self, application_type='ruby'):
+        self.application_type = application_type
 
     def prepare_env(self, script):
         shutil.copytree(
-            option.test_dir + '/ruby/' + script,
-            option.temp_dir + '/ruby/' + script,
+            f'{option.test_dir}/ruby/{script}',
+            f'{option.temp_dir}/ruby/{script}',
         )
 
-        public_dir(option.temp_dir + '/ruby/' + script)
+        public_dir(f'{option.temp_dir}/ruby/{script}')
 
     def load(self, script, name='config.ru', **kwargs):
         self.prepare_env(script)
 
-        script_path = option.temp_dir + '/ruby/' + script
+        script_path = f'{option.temp_dir}/ruby/{script}'
 
         app = {
             "type": self.get_application_type(),
             "processes": {"spare": 0},
             "working_directory": script_path,
-            "script": script_path + '/' + name,
+            "script": f'{script_path}/{name}',
         }
 
         for key in [
@@ -36,8 +37,8 @@ class TestApplicationRuby(TestApplicationProto):
 
         self._load_conf(
             {
-                "listeners": {"*:7080": {"pass": "applications/" + script}},
+                "listeners": {"*:8080": {"pass": f"applications/{script}"}},
                 "applications": {script: app},
             },
-            **kwargs
+            **kwargs,
         )
