@@ -1,6 +1,6 @@
 import json
 
-from unit.http import TestHTTP
+from unit.http import HTTP1
 from unit.option import option
 
 
@@ -16,12 +16,12 @@ def args_handler(conf_func):
         elif argcount == 3:
             conf = args[0]
 
-            if isinstance(conf, dict) or isinstance(conf, list):
+            if isinstance(conf, (dict, list)):
                 conf = json.dumps(conf)
 
             url = args[1] if len(args) == 2 else url_default
 
-        url = url if url.startswith('/') else url_default + '/' + url
+        url = url if url.startswith('/') else f'{url_default}/{url}'
         arguments = (self, url) if conf is None else (self, conf, url)
 
         return json.loads(conf_func(*arguments))
@@ -29,11 +29,7 @@ def args_handler(conf_func):
     return args_wrapper
 
 
-class TestControl(TestHTTP):
-
-    # TODO socket reuse
-    # TODO http client
-
+class Control(HTTP1):
     @args_handler
     def conf(self, conf, url):
         return self.put(**self._get_args(url, conf))['body']
@@ -54,7 +50,7 @@ class TestControl(TestHTTP):
         args = {
             'url': url,
             'sock_type': 'unix',
-            'addr': option.temp_dir + '/control.unit.sock',
+            'addr': f'{option.temp_dir}/control.unit.sock',
         }
 
         if conf is not None:
